@@ -115,6 +115,12 @@ def run():
 
 def cmd_use(name, job=None):
     container = Container(name)
+
+    if container.is_remote():
+        print("Sourcing remote container..")
+    else:
+        print("Sourcing local container..")
+
     revision = container.get_latest_revision()
 
     if not revision:
@@ -124,7 +130,7 @@ def cmd_use(name, job=None):
             sys.exit(1)
 
         elif container.name() != Container.DEFAULT_NAME:
-            print("Container '%s' not exist, use --make to create."
+            print("Container '%s' not exist, use 'rezup add' to create."
                   % container.name())
             sys.exit(1)
 
@@ -132,7 +138,8 @@ def cmd_use(name, job=None):
             # for quick first run
             print("Creating default container automatically for first "
                   "run..")
-            revision = container.new_revision()
+            recipe = Container.recipe_file(name, ensure_exists=True)
+            revision = container.new_revision(recipe_file=recipe)
 
     sys.exit(
         revision.use(run_script=job)
@@ -140,7 +147,18 @@ def cmd_use(name, job=None):
 
 
 def cmd_add(name, remote=False, recipe=None, skip_use=False):
-    root = Container.remote_root() if remote else Container.local_root()
+    recipe = recipe or Container.recipe_file(name, ensure_exists=False)
+    if not os.path.isfile(recipe):
+        print("Recipe file not exists: %s" % os.path.abspath(recipe))
+        sys.exit(1)
+
+    if remote:
+        print("Creating remote container..")
+        root = Container.remote_root()
+    else:
+        print("Creating local container..")
+        root = Container.local_root()
+
     container = Container.create(name, root=root)
     revision = container.new_revision(recipe_file=recipe)
 
